==> redpesk-cli_3.15.0.orig.tar.gz: redpesk-cli-3.15.0/rpxxxapi/bckapi/bck_boards.go <==
/**
 * Copyright (C) 2022-2023 IoT.bzh Company
 * Contact: https://www.iot.bzh/licensing
 *
 * This file is part of the redpesk-cli project, the redpesk command line tool.
 *
 * $RP_BEGIN_LICENSE$
 * Commercial License Usage
 *  Licensees holding valid commercial IoT.bzh licenses may use this file in
 *  accordance with the commercial license agreement provided with the
 *  Software or, alternatively, in accordance with the terms contained in
 *  a written agreement between you and The IoT.bzh Company. For licensing terms
 *  and conditions see https://www.iot.bzh/terms-conditions. For further
 *  information use the contact form at https://www.iot.bzh/contact.
 *
 * GNU General Public License Usage
 *  Alternatively, this file may be used under the terms of the GNU General
 *  Public license version 3. This license is as published by the Free Software
 *  Foundation and appearing in the file LICENSE.GPLv3 included in the packaging
 *  of this file. Please review the following information to ensure the GNU
 *  General Public License requirements will be met
 *  https://www.gnu.org/licenses/gpl-3.0.html.
 * $RP_END_LICENSE$
 */

package bckapi

import (
	"encoding/json"
	"strconv"

	"git.ovh.iot/redpesk/redpesk-infra/rp-webserver/actions/rpapiv1"
)

var cachedBoards = []rpapiv1.RPBoard{}

// RPBoardsGet allows to get the list of available boards
// on the Redpesk instance
//
// :param boards: Pointer to []RPBoard slice to be filled
// :type boards: *rpapiv1.RPBoard
// :param forceReq: Boolean allowing to force the HTTP request
// :type forceReq: bool
// :returns: error -- an error if something went bad
func (rpAPIInterface *RPBCKAPI) RPBoardsGet(boards *[]rpapiv1.RPBoard, forceReq bool) error {

	// Send the request if the cache is empty or it is forced
	if len(cachedBoards) == 0 || forceReq {

		// Reset our cache
		cachedBoards = []rpapiv1.RPBoard{}

		// Initialize the call-back to save current page of boards
		savingCB := func(tmpObjects []byte) {
			tmpBoards := rpapiv1.RPBoards{}
			// Convert to the right type
			json.Unmarshal(tmpObjects, &tmpBoards)
			// Add the applications in the final object
			cachedBoards = append(cachedBoards, tmpBoards.Boards...)
		}

		// Initialize the paging structure that will allow to get all the objects
		pagingMngt := &RPBCKPaging{}

		// Call the function allowing to get all the object
		err := pagingMngt.getAllObjects(rpAPIInterface, boardsRoute, "", nil, savingCB)
		if err != nil {
			return errorInterpreter(err, boardObjectType)
		}
	}

	// Copy the boards
	(*boards) = append((*boards), cachedBoards...)

	return nil
}

// RPBoardsListByPage gets the list of boards on the factory
// but only one page of it
//
// :param boards: Pointer to structure to be filled
// :type boards: *rpapiv1.RPBoards
// :param page: Page number that the caller want
// :type page: int
// :param perPage: Number of item per page that the caller want
// :type perPage: int
// :returns: error -- an error if a problem has occurred
func (rpAPIInterface *RPBCKAPI) RPBoardsListByPage(boards *rpapiv1.RPBoards, page, perPage int) error {

	// Initialize the query parameters object
	queryParamMap := map[string]string{
		"page":     strconv.Itoa(page),
		"per_page": strconv.Itoa(perPage),
	}

	// Now, run the get request
	if err := rpAPIInterface.HTTPCli.Get(boardsRoute, boards, queryParamMap); err != nil {
		return errorInterpreter(err, boardObjectType)
	}

	return nil
}

==> redpesk-cli_3.18.3.orig.tar.gz: redpesk-cli-3.18.3/rpxxxapi/bckapi/bck_boards.go <==
/**
 * Copyright (C) 2022-2023 IoT.bzh Company
 * Contact: https://www.iot.bzh/licensing
 *
 * This file is part of the redpesk-cli project, the redpesk command line tool.
 *
 * $RP_BEGIN_LICENSE$
 * Commercial License Usage
 *  Licensees holding valid commercial IoT.bzh licenses may use this file in
 *  accordance with the commercial license agreement provided with the
 *  Software or, alternatively, in accordance with the terms contained in
 *  a written agreement between you and The IoT.bzh Company. For licensing terms
 *  and conditions see https://www.iot.bzh/terms-conditions. For further
 *  information use the contact form at https://www.iot.bzh/contact.
 *
 * GNU General Public License Usage
 *  Alternatively, this file may be used under the terms of the GNU General
 *  Public license version 3. This license is as published by the Free Software
 *  Foundation and appearing in the file LICENSE.GPLv3 included in the packaging
 *  of this file. Please review the following information to ensure the GNU
 *  General Public License requirements will be met
 *  https://www.gnu.org/licenses/gpl-3.0.html.
 * $RP_END_LICENSE$
 */

package bckapi

import (
	"encoding/json"
	"strconv"

	"git.ovh.iot/redpesk/redpesk-infra/rp-webserver/actions/rpapiv1"
)

// RPBoardsGet allows to get the list of available boards
// on the Redpesk instance
//
// :param boards: Pointer to []RPBoard slice to be filled
// :type boards: *rpapiv1.RPBoard
// :param filter: Filter to pass to the request done to the factory
// :type filter: string
// :returns: error -- an error if something went bad
func (rpAPIInterface *RPBCKAPI) RPBoardsGet(boards *[]rpapiv1.RPBoard, filter string) error {

	addQueryParams := make(map[string]string)
	if filter != "" {
		addQueryParams["filters"] = filter
	}

	// Initialize the call-back to save current page of boards
	savingCB := func(tmpObjects []byte) {
		tmpBoards := rpapiv1.RPBoards{}
		// Convert to the right type
		json.Unmarshal(tmpObjects, &tmpBoards)
		// Add the applications in the final object
		(*boards) = append((*boards), tmpBoards.Boards...)
	}

	// Initialize the paging structure that will allow to get all the objects
	pagingMngt := &RPBCKPaging{}

	// Call the function allowing to get all the object
	err := pagingMngt.getAllObjects(rpAPIInterface, boardsRoute, "", addQueryParams, savingCB)
	if err != nil {
		return errorInterpreter(err, boardObjectType)
	}

	return nil
}

// RPBoardsListByPage gets the list of boards on the factory
// but only one page of it
//
// :param boards: Pointer to structure to be filled
// :type boards: *rpapiv1.RPBoards
// :param page: Page number that the caller want
// :type page: int
// :param perPage: Number of item per page that the caller want
// :type perPage: int
// :returns: error -- an error if a problem has occurred
func (rpAPIInterface *RPBCKAPI) RPBoardsListByPage(boards *rpapiv1.RPBoards, page, perPage int) error {

	// Initialize the query parameters object
	queryParamMap := map[string]string{
		"page":     strconv.Itoa(page),
		"per_page": strconv.Itoa(perPage),
	}

	// Now, run the get request
	if err := rpAPIInterface.HTTPCli.Get(boardsRoute, boards, queryParamMap); err != nil {
		return errorInterpreter(err, boardObjectType)
	}

	return nil
}
